@@ -12,6 +12,7 @@ from confluent_kafka.admin import ConfigResource
 from confluent_kafka.cimpl import KafkaException, NewTopic, TopicPartition
 
 from esque.config import ESQUE_GROUP_ID, Config
+from esque.errors import TopicDeletionException
 from esque.helpers import ensure_kafka_future_done
 from esque.resources.topic import Partition, Topic, TopicDiff
 
@@ -35,6 +36,7 @@ class TopicController:
         sort: bool = True,
         hide_internal: bool = False,
         get_topic_objects: bool = True,
+        get_partitions: bool = True,
     ) -> List[Topic]:
         topic_results = self.cluster.confluent_client.list_topics().topics.values()
         topic_names = [t.topic for t in topic_results]
@@ -46,7 +48,10 @@ class TopicController:
             topic_names = sorted(topic_names)
 
         if get_topic_objects:
-            topics = list(map(self.get_cluster_topic, topic_names))
+            topics = [
+                self.get_cluster_topic(topic_name, retrieve_partition_data=get_partitions)
+                for topic_name in topic_names
+            ]
         else:
             topics = list(map(self.get_local_topic, topic_names))
         return topics
@@ -92,13 +97,30 @@ class TopicController:
             altered_config[name] = value
         return altered_config
 
-    def delete_topic(self, topic: Topic):
-        future = self.cluster.confluent_client.delete_topics([topic.name])[topic.name]
-        ensure_kafka_future_done(future)
+    def delete_topic(self, topic: Topic) -> bool:
+        return self.delete_topics([topic])
 
-    def get_cluster_topic(self, topic_name: str, *, retrieve_last_timestamp: bool = False) -> Topic:
+    def delete_topics(self, topics: List[Topic]) -> bool:
+        futures = self.cluster.confluent_client.delete_topics([topic.name for topic in topics], operation_timeout=60)
+        errors: List[str] = []
+        for topic_name, future in futures.items():
+            try:
+                future.result()
+            except KafkaException as e:
+                errors.append(f"[{topic_name}]: {e.args[0].str()}")
+        if errors:
+            raise TopicDeletionException("The following exceptions occurred:\n " + "\n ".join(sorted(errors)))
+        return True
+
+    def get_cluster_topic(
+        self, topic_name: str, *, retrieve_last_timestamp: bool = False, retrieve_partition_data: bool = True
+    ) -> Topic:
         """Convenience function getting an existing topic based on topic_name"""
-        return self.update_from_cluster(Topic(topic_name), retrieve_last_timestamp=retrieve_last_timestamp)
+        return self.update_from_cluster(
+            Topic(topic_name),
+            retrieve_last_timestamp=retrieve_last_timestamp,
+            retrieve_partition_data=retrieve_partition_data,
+        )
 
     def get_local_topic(self, topic_name: str) -> Topic:
         return Topic(topic_name)
@@ -119,23 +141,37 @@ class TopicController:
             topic_partition.partition: topic_partition.offset for topic_partition in topic_partitions_with_new_offsets
         }
 
-    def update_from_cluster(self, topic: Topic, *, retrieve_last_timestamp: bool = False) -> Topic:
+    def update_from_cluster(
+        self, topic: Topic, *, retrieve_last_timestamp: bool = False, retrieve_partition_data: bool = True
+    ) -> Topic:
         """Takes a topic and, based on its name, updates all attributes from the cluster"""
 
-        topic.partition_data = self._get_partition_data(topic, retrieve_last_timestamp)
+        topic.partition_data = self._get_partitions(
+            topic, retrieve_last_timestamp, get_partition_data=retrieve_partition_data
+        )
         topic.config = self.cluster.retrieve_config(ConfigResource.Type.TOPIC, topic.name)
 
         topic.is_only_local = False
 
         return topic
 
-    def _get_partition_data(self, topic: Topic, retrieve_last_timestamp: bool) -> List[Partition]:
+    def _get_partitions(
+        self, topic: Topic, retrieve_last_timestamp: bool, get_partition_data: bool = True
+    ) -> List[Partition]:
+        assert not (
+            retrieve_last_timestamp and not get_partition_data
+        ), "Can not retrieve timestamp without partition data"
 
         config = Config.get_instance().create_confluent_config()
         config.update({"group.id": ESQUE_GROUP_ID, "topic.metadata.refresh.interval.ms": "250"})
         with closing(confluent_kafka.Consumer(config)) as consumer:
             confluent_topic = consumer.list_topics(topic=topic.name).topics[topic.name]
             partitions: List[Partition] = []
+            if not get_partition_data:
+                return [
+                    Partition(partition_id, -1, -1, meta.isrs, meta.leader, meta.replicas, None)
+                    for partition_id, meta in confluent_topic.partitions.items()
+                ]
             for partition_id, meta in confluent_topic.partitions.items():
                 try:
                     low, high = consumer.get_watermark_offsets(
@@ -168,7 +204,7 @@ class TopicController:
     def diff_with_cluster(self, local_topic: Topic) -> TopicDiff:
         assert local_topic.is_only_local, "Can only diff local topics with remote"
 
-        cluster_topic = self.get_cluster_topic(local_topic.name)
+        cluster_topic = self.get_cluster_topic(local_topic.name, retrieve_partition_data=False)
         diffs = TopicDiff()
         diffs.set_diff("num_partitions", cluster_topic.num_partitions, local_topic.num_partitions)
         diffs.set_diff("replication_factor", cluster_topic.replication_factor, local_topic.replication_factor)
